@@ -9,7 +9,7 @@ SWITCH = "switch"
 LIGHT = "light"
 
 # device types
-DEVICE_TYPE_DICT = {"01": SWITCH}
+DEVICE_TYPE_DICT = {"02": SWITCH}
 
 DISCOVERY_TIMEOUT_IN_SEC = 5
 
@@ -20,29 +20,42 @@ FRAGMENT_DEVICE_TYPE = "fragment_device_type"
 FRAGMENT_UNIQUE_ID = "fragment_unique_id"
 
 MQTT_BROKER_CLIENT_NAME = "inels-mqtt"
-MQTT_DISCOVER_TOPIC = "inels/#"
+MQTT_DISCOVER_TOPIC = "inels/status/#"
 
 TOPIC_FRAGMENTS = {
     FRAGMENT_DOMAIN: 0,
-    FRAGMENT_SERIAL_NUMBER: 1,
-    FRAGMENT_STATE: 2,
+    FRAGMENT_STATE: 1,
+    FRAGMENT_SERIAL_NUMBER: 2,
     FRAGMENT_DEVICE_TYPE: 3,
     FRAGMENT_UNIQUE_ID: 4,
 }
 
-SWITCH_ON = "FF\\n50\\n32\\nAC\\n"
-SWITCH_OFF = "FF\\nFF\\nFF\\nFF\\n"
+DEVICE_CONNCTED = {
+    "on": True,
+    "off": False,
+}
+
+SWITCH_ON_STATE = "02\\n01\\n"
+SWITCH_OFF_STATE = "02\\n00\\n"
+
+SWITCH_ON_SET = "01\\n00\\n00\\n"
+SWITCH_OFF_SET = "02\\n00\\n00\\n"
+
+SWITCH_SET = {
+    True: SWITCH_ON_SET,
+    False: SWITCH_OFF_SET,
+}
 
 SWITCH_STATE = {
-    SWITCH_ON: True,
-    SWITCH_OFF: False,
+    SWITCH_ON_STATE: True,
+    SWITCH_OFF_STATE: False,
 }
 
 LIGHT_ON = "Aadfadfadf"
 LIGHT_OFF = "adfwerafad"
 
 DEVICE_PLATFORMS = {
-    SWITCH: {SWITCH_ON: True, SWITCH_OFF: False},
+    SWITCH: {SWITCH_ON_STATE: True, SWITCH_OFF_STATE: False},
     LIGHT: {LIGHT_ON: True, LIGHT_OFF: False},
 }
 
