@@ -10,5 +10,6 @@ TEST_DEBUG_FALSE = False
 TEST_INELS_MQTT_NAMESPACE = "inelsmqtt"
 TEST_INELS_MQTT_CLASS_NAMESPACE = "inelsmqtt.InelsMqtt"
 
-TEST_TOPIC_STATE = "inels/4254524524/status/01/452454"
-TEST_TOPIC_SET = "inels/4254524524/set/01/452454"
+TEST_TOPIC_STATE = "inels/status/4254524524/02/452454"
+TEST_TOPIC_SET = "inels/set/4254524524/02/452454"
+TEST_TOPIC_CONNECTED = "inels/connected/4254524524/02/452454"
