@@ -12,8 +12,10 @@ from inelsmqtt.const import (
     FRAGMENT_DOMAIN,
     FRAGMENT_SERIAL_NUMBER,
     FRAGMENT_UNIQUE_ID,
-    SWITCH_ON,
-    SWITCH_OFF,
+    SWITCH_OFF_SET,
+    SWITCH_ON_SET,
+    SWITCH_ON_STATE,
+    SWITCH_OFF_STATE,
     TOPIC_FRAGMENTS,
     MQTT_HOST,
     MQTT_PORT,
@@ -24,6 +26,7 @@ from inelsmqtt.const import (
 )
 
 from tests.const import (
+    TEST_TOPIC_CONNECTED,
     TEST_TOPIC_STATE,
     TEST_INELS_MQTT_NAMESPACE,
     TEST_INELS_MQTT_CLASS_NAMESPACE,
@@ -49,6 +52,7 @@ class DeviceTest(TestCase):
                 f"{TEST_INELS_MQTT_NAMESPACE}.mqtt.Client.username_pw_set",
                 return_value=Mock(),
             ),
+            patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.subscribe", return_value=Mock()),
             patch(f"{TEST_INELS_MQTT_NAMESPACE}._LOGGER", return_value=Mock()),
         ]
 
@@ -89,7 +93,7 @@ class DeviceTest(TestCase):
 
         fragments = TEST_TOPIC_STATE.split("/")
 
-        set_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/set/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: 501
+        set_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/set/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: 501
 
         self.assertEqual(
             dev_no_title.unique_id, fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]
@@ -112,21 +116,23 @@ class DeviceTest(TestCase):
         self.assertTrue(self.device.set_ha_value(True))
 
         # SWITCH_ON needs to be encoded becasue broker returns value as a byte
-        mock_messages.return_value = {TEST_TOPIC_STATE: SWITCH_ON.encode()}
+        mock_messages.return_value = {TEST_TOPIC_STATE: SWITCH_ON_STATE.encode()}
         mock_publish.return_value = True
 
         rt_val = self.device.get_value()
         self.assertTrue(rt_val.ha_value)
-        self.assertEqual(rt_val.inels_value, SWITCH_ON)
+        self.assertEqual(rt_val.inels_status_value, SWITCH_ON_STATE)
+        self.assertEqual(rt_val.inels_set_value, SWITCH_ON_SET)
 
         self.assertTrue(self.device.set_ha_value(False))
 
-        mock_messages.return_value = {TEST_TOPIC_STATE: SWITCH_OFF.encode()}
+        mock_messages.return_value = {TEST_TOPIC_STATE: SWITCH_OFF_STATE.encode()}
         mock_publish.return_value = False
 
         rt_val = self.device.get_value()
         self.assertFalse(rt_val.ha_value)
-        self.assertEqual(rt_val.inels_value, SWITCH_OFF)
+        self.assertEqual(rt_val.inels_status_value, SWITCH_OFF_STATE)
+        self.assertEqual(rt_val.inels_set_value, SWITCH_OFF_SET)
 
     def test_info_serialized(self) -> None:
         """Test of the serialized info."""
@@ -139,3 +145,21 @@ class DeviceTest(TestCase):
 
         self.assertIsInstance(info, DeviceInfo)
         self.assertEqual(info.manufacturer, fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]])
+
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages", new_callable=PropertyMock)
+    def test_is_available(self, mock_messages) -> None:
+        """Test of the device availability."""
+
+        mock_messages.return_value = {TEST_TOPIC_CONNECTED: "on"}
+        is_avilable = self.device.is_available
+
+        self.assertTrue(is_avilable)
+
+    @patch(f"{TEST_INELS_MQTT_CLASS_NAMESPACE}.messages", new_callable=PropertyMock)
+    def test_is_not_available(self, mock_messages) -> None:
+        """Test of the dvice availability wit result false."""
+
+        mock_messages.return_value = {TEST_TOPIC_CONNECTED: "off"}
+        is_avilable = self.device.is_available
+
+        self.assertFalse(is_avilable)
